==> e16-0.16.8.10.tar.gz: e16-0.16.8.10/config/strings.c <==
#define _(x) x

const char *txt[] = {
/* actionclasses.cfg */
_("Click and drag to move desktop\n(on any desktop but desktop 0)"),
_("Switch Desktops"),
_("Go to the next desktop."),
_("Switch Desktops"),
_("Go to the previous desktop."),
_("Move"),
_("Move this window."),
_("Shade/Unshade this window."),
_("Show the Window Options menu."),
_("Shade/Unshade this window."),
_("Show/Hide group borders."),
_("Start a group."),
_("Add to current group."),
_("Break this window's group."),
_("Shade."),
_("Unshade."),
_("Resize"),
_("Resize this window."),
_("Move this window."),
_("Resize Horizontally"),
_("Resize this window horizontally."),
_("Move this window."),
_("Resize Vertically"),
_("Resize this window vertically."),
_("Move this window."),
_("Close"),
_("Close this window."),
_("Forcibly destroy this window."),
_("Maximize Height"),
_("Toggle between maximum screen height and normal height."),
_("Maximize Width"),
_("Toggle between maximum screen width and normal width."),
_("Maximize"),
_("Toggle between maximum screen size and normal size."),
_("Toggle between maximum screen width and normal width."),
_("Toggle between maximum screen height and normal height."),
_("Send To Another Desktop"),
_("Send this Window to the next desktop."),
_("Send To Another Desktop"),
_("Send this Window to the previous desktop."),
_("Snapshot"),
_("This button does nothing interesting."),
_("Shade/Unshade"),
_("Shade/Unshade this window."),
_("Window Options"),
_("Show the Window Options menu."),
_("Iconify"),
_("Iconify (Minimize) this window."),
_("Show the Window Options menu."),
_("More Buttons"),
_("Show more buttons."),
_("Raise"),
_("Raise this window to the top."),
_("Lower"),
_("Lower this window."),
_("Stick/Unstick"),
_("Toggle the Omnipresent (visible on all Desktops) state of this window."),
/* bindings.cfg */
_("Clicking your mouse on the desktop will perform\nthe following actions"),
_("Display User Menus"),
_("Display Enlightenment Menu"),
_("Display Settings Menu"),
_("Display Enlightenment Menu"),
_("Display Task List Menu"),
_("Display Desktop Menu"),
_("Display Group Menu"),
_("Display Settings Menu"),
_("Go Back a Desktop"),
_("Go Forward a Desktop"),
/* matches.cfg */
/* menus.cfg */
_("Backgrounds"),
/* desktop.menu */
_("Desktop Operations"),
_("Backgrounds"),
_("Cleanup Desktop"),
_("Goto Next Desktop"),
_("Goto Previous Desktop"),
_("Create New Iconbox"),
_("Create Systray"),
/* enlightenment.menu */
_("Enlightenment"),
_("User Menus"),
_("Desktop"),
_("Settings"),
_("Themes"),
_("Maintenance"),
_("Help"),
_("About Enlightenment"),
_("About this theme"),
_("Restart Enlightenment"),
_("Log Out"),
/* maintenance.menu */
_("Maintenance"),
_("Purge config file cache"),
_("Purge pager background cache"),
_("Purge background selector cache"),
_("Purge all caches"),
_("Query config file cache usage"),
_("Query pager background cache usage"),
_("Query background selector cache usage"),
_("Query all cache usage"),
_("Regenerate Menus"),
/* settings.menu */
_("Settings"),
_("Enlightenment Settings ..."),
_("Focus Settings ..."),
_("Move & Resize Settings ..."),
_("Window Placement Settings ..."),
_("Multiple Desktop Settings ..."),
_("Virtual Desktop Settings ..."),
_("Pager Settings ..."),
_("Menu Settings ..."),
_("Autoraise Settings ..."),
_("Tooltip Settings ..."),
_("Audio Settings ..."),
_("Group Settings ..."),
_("Remember Settings ..."),
_("Special FX Settings ..."),
_("Desktop Background Settings ..."),
_("Theme Transparency Settings ..."),
_("Composite Settings ..."),
_("Session Settings ..."),
_("Miscellaneous Settings ..."),
/* winops.menu */
_("Window Options"),
_("Close"),
_("Annihilate"),
_("Iconify"),
_("Raise"),
_("Lower"),
_("Shade/Unshade"),
_("Stick/Unstick"),
_("Remember..."),
_("Window Size"),
_("Set Stacking"),
_("Set Border Style"),
_("Window Groups"),
_("Opacity"),
_("Miscellaneous"),
/* winops_groups.menu */
_("Groups"),
_("Configure this window's group(s)"),
_("Start a new group"),
_("Add this window to the current group"),
_("Select group to add this window to"),
_("Remove this window from a group"),
_("Destroy a group this window belongs to"),
/* winops_layer.menu */
_("Stacking"),
_("Below"),
_("Normal"),
_("Above"),
_("On Top"),
/* winops_misc.menu */
_("Miscellaneous"),
_("Toggle Skip Window Lists"),
_("Toggle Fixed Position"),
_("Toggle Fixed Size"),
_("Toggle Never Focus"),
_("Toggle Click to Focus"),
_("Toggle Never Use Area"),
_("Toggle Button Grabs"),
/* winops_opacity.menu */
_("Opacity"),
_("20%"),
_("40%"),
_("60%"),
_("80%"),
_("100%"),
_("Focused opacity 100%"),
_("Focused opacity follows unfocused"),
_("Toggle Fading"),
_("Toggle Shadows"),
/* winops_size.menu */
_("Size"),
_("Max Size Toggle"),
_("Available Max Size Toggle"),
_("Absolute Max Size Toggle"),
_("Span Xinerama Screens"),
_("Max Height Toggle"),
_("Available Max Height Toggle"),
_("Absolute Max Height Toggle"),
_("Max Width Toggle"),
_("Available Max Width Toggle"),
_("Absolute Max Width Toggle"),
_("Fullscreen/Normal"),
_("Zoom/Unzoom"),

_("User Menus"),
_("User Application List"),
_("Other"),
_("Enlightenment Epplets"),
_("Restart Enlightenment"),
_("Log Out"),
};

==> e16_0.16.8.13.orig.tar.gz: e16-0.16.8.13/config/strings.c <==
#define _(x) x

const char *txt[] = {
/* actionclasses.cfg */
_("Click and drag to move desktop\n(on any desktop but desktop 0)"),
_("Switch Desktops"),
_("Go to the next desktop."),
_("Switch Desktops"),
_("Go to the previous desktop."),
_("Move"),
_("Move this window."),
_("Shade/Unshade this window."),
_("Show the Window Options menu."),
_("Shade/Unshade this window."),
_("Show/Hide group borders."),
_("Start a group."),
_("Add to current group."),
_("Break this window's group."),
_("Shade."),
_("Unshade."),
_("Resize"),
_("Resize this window."),
_("Move this window."),
_("Resize Horizontally"),
_("Resize this window horizontally."),
_("Move this window."),
_("Resize Vertically"),
_("Resize this window vertically."),
_("Move this window."),
_("Close"),
_("Close this window."),
_("Forcibly destroy this window."),
_("Maximize Height"),
_("Toggle between maximum screen height and normal height."),
_("Maximize Width"),
_("Toggle between maximum screen width and normal width."),
_("Maximize"),
_("Toggle between maximum screen size and normal size."),
_("Toggle between maximum screen width and normal width."),
_("Toggle between maximum screen height and normal height."),
_("Send To Another Desktop"),
_("Send this Window to the next desktop."),
_("Send To Another Desktop"),
_("Send this Window to the previous desktop."),
_("Snapshot"),
_("This button does nothing interesting."),
_("Shade/Unshade"),
_("Shade/Unshade this window."),
_("Window Options"),
_("Show the Window Options menu."),
_("Iconify"),
_("Iconify (Minimize) this window."),
_("Show the Window Options menu."),
_("More Buttons"),
_("Show more buttons."),
_("Raise"),
_("Raise this window to the top."),
_("Lower"),
_("Lower this window."),
_("Stick/Unstick"),
_("Toggle the Omnipresent (visible on all Desktops) state of this window."),
/* bindings.cfg */
_("Clicking your mouse on the desktop will perform\nthe following actions"),
_("Display User Menus"),
_("Display Enlightenment Menu"),
_("Display Settings Menu"),
_("Display Enlightenment Menu"),
_("Display Task List Menu"),
_("Display Desktop Menu"),
_("Display Group Menu"),
_("Display Settings Menu"),
_("Go Back a Desktop"),
_("Go Forward a Desktop"),
/* matches.cfg */
/* menus.cfg */
_("Backgrounds"),
/* desktop.menu */
_("Desktop Operations"),
_("Backgrounds"),
_("Cleanup Desktop"),
_("Goto Next Desktop"),
_("Goto Previous Desktop"),
_("Create New Iconbox"),
_("Create Systray"),
_("Show Magnifier"),
/* enlightenment.menu */
_("Enlightenment"),
_("User Menus"),
_("Desktop"),
_("Settings"),
_("Themes"),
_("Maintenance"),
_("Help"),
_("About Enlightenment"),
_("About this theme"),
_("Restart"),
_("Log Out"),
/* maintenance.menu */
_("Maintenance"),
_("Purge config file cache"),
_("Purge pager background cache"),
_("Purge background selector cache"),
_("Purge all caches"),
_("Query config file cache usage"),
_("Query pager background cache usage"),
_("Query background selector cache usage"),
_("Query all cache usage"),
_("Regenerate Menus"),
/* settings.menu */
_("Settings"),
_("Enlightenment Settings ..."),
_("Focus Settings ..."),
_("Move & Resize Settings ..."),
_("Window Placement Settings ..."),
_("Multiple Desktop Settings ..."),
_("Virtual Desktop Settings ..."),
_("Pager Settings ..."),
_("Menu Settings ..."),
_("Autoraise Settings ..."),
_("Tooltip Settings ..."),
_("Audio Settings ..."),
_("Group Settings ..."),
_("Remember Settings ..."),
_("Special FX Settings ..."),
_("Desktop Background Settings ..."),
_("Theme Transparency Settings ..."),
_("Composite Settings ..."),
_("Session Settings ..."),
_("Miscellaneous Settings ..."),
/* winops.menu */
_("Window Options"),
_("Close"),
_("Annihilate"),
_("Iconify"),
_("Raise"),
_("Lower"),
_("Shade/Unshade"),
_("Stick/Unstick"),
_("Remember..."),
_("Window Size"),
_("Set Stacking"),
_("Set Border Style"),
_("Window Groups"),
_("Opacity"),
_("Miscellaneous"),
/* winops_groups.menu */
_("Groups"),
_("Configure this window's group(s)"),
_("Start a new group"),
_("Add this window to the current group"),
_("Select group to add this window to"),
_("Remove this window from a group"),
_("Destroy a group this window belongs to"),
/* winops_layer.menu */
_("Stacking"),
_("Below"),
_("Normal"),
_("Above"),
_("On Top"),
/* winops_misc.menu */
_("Miscellaneous"),
_("Toggle Skip Window Lists"),
_("Toggle Fixed Position"),
_("Toggle Fixed Size"),
_("Toggle Never Focus"),
_("Toggle Click to Focus"),
_("Toggle Never Use Area"),
_("Toggle Button Grabs"),
/* winops_opacity.menu */
_("Opacity"),
_("20%"),
_("40%"),
_("60%"),
_("80%"),
_("100%"),
_("Focused opacity 100%"),
_("Focused opacity follows unfocused"),
_("Toggle Fading"),
_("Toggle Shadows"),
/* winops_size.menu */
_("Size"),
_("Max Size Toggle"),
_("Available Max Size Toggle"),
_("Absolute Max Size Toggle"),
_("Span Xinerama Screens"),
_("Max Height Toggle"),
_("Available Max Height Toggle"),
_("Absolute Max Height Toggle"),
_("Max Width Toggle"),
_("Available Max Width Toggle"),
_("Absolute Max Width Toggle"),
_("Fullscreen/Normal"),
_("Zoom/Unzoom"),

_("User Menus"),
_("User Application List"),
_("Other"),
_("Epplets"),
_("Restart"),
_("Log Out"),
};
